@@ -10,9 +10,12 @@
 import logging
 import warnings
 from dataclasses import dataclass
+from io import BytesIO
 from typing import Optional
 
+from aiohttp import FormData
 from http_tools import AbmServiceConnector
+from http_tools.mime_types import ContentType
 from init_helpers.dict_to_dataclass import dict_to_dataclass
 
 
@@ -87,14 +90,28 @@ class FileServerConnector:
         answer = await self._connector.get("/file/info", args, headers=self._construct_headers())
         return dict_to_dataclass(answer, FileLink)
 
-    async def add_file(self, file: bytes, filename: str, is_thumbnail_required: bool = False) -> FileLink:
-        args = {"filename": filename, "is_thumbnail_required": str(is_thumbnail_required).lower()}
-        answer = await self._connector.post("/file/add", payload=file, url_query=args,
-                                            headers=self._construct_headers())
+    async def get_thumbnail(self, file_id: str) -> bytes:
+        return await self._connector.get("file/preview", {"id": file_id}, headers=self._construct_headers())
+
+    async def upload_file(
+            self, filename: str, content: bytes, is_thumbnail_required: bool = False
+    ) -> tuple[FileLink, FileLink | None]:
+        form_data = FormData()
+        is_thumbnail_required = str(is_thumbnail_required).lower()
+        form_data.add_field("is_thumbnail_required", is_thumbnail_required, content_type=ContentType.Text.value)
+        form_data.add_field("file", BytesIO(content), filename=filename)
+        answer = await self._connector.post("/file/add", payload=form_data, headers=self._construct_headers())
         original = answer.get("original")
         if not original:
             raise ValueError(f'Wrong answer: {answer}')
-        return dict_to_dataclass(original, FileLink)
+        original = dict_to_dataclass(original, FileLink)
+        if thumbnail := answer.get("thumbnail"):
+            thumbnail = dict_to_dataclass(thumbnail, FileLink)
+        return original, thumbnail
+
+    async def add_file(self, file: bytes, filename: str, **kwargs) -> FileLink:
+        warnings.warn("'add_file' is deprecated, replace it with 'upload_file'", DeprecationWarning)
+        return (await self.upload_file(filename, file))[0]
 
     async def delete_file(self, file_id: str) -> FileLink:
         args = {"id": file_id}
